---
sidebar_position: 1
---
# Installation 
You can install `pylocc` from sources or from pypi.

## Requirements

- Python >= 3.10


### Install From Pypi
```bash
 pip install pylocc

 pylocc --help
 ```
### Install From Source

1.  Clone the repository:
    ```bash
    git clone https://github.com/your-username/pylocc.git
    ```
2.  Navigate to the project directory:
    ```bash
    cd pylocc
    ```
3.  Install the dependencies:
    ```bash
    uv run pylocc
    ```
